/*
 * Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.
 * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/*
 * $Id:
 */
package com.sun.ts.tests.jsf.api.javax_faces.event.postvalidateevent;

import java.io.PrintWriter;
import com.sun.javatest.Status;
import com.sun.ts.tests.jsf.common.client.AbstractUrlClient;

public final class URLClient extends AbstractUrlClient {

	private static final String CONTEXT_ROOT = "/jsf_event_postvalidateevent_web";

	public static void main(String[] args) {
		URLClient theTests = new URLClient();
		Status s = theTests.run(args, new PrintWriter(System.out, true),
				new PrintWriter(System.err, true));
		s.exit();
	}

	public Status run(String[] args, PrintWriter out, PrintWriter err) {
		setContextRoot(CONTEXT_ROOT);
		setServletName(DEFAULT_SERVLET_NAME);
		return super.run(args, out, err);
	}

	/*
	 * @class.setup_props: webServerHost; webServerPort; ts_home;
	 */

	/* Test Declarations */

	/**
	 * @testName: postValidateEventCtorTest
	 * @assertion_ids: JSF:JAVADOC:1862
	 * @test_Strategy: Ensure Instantiate a new PostValidateEvent that indicates
	 *                 the argument component was just added to the view.
	 * 
	 * @since 2.0
	 */
	public void postValidateEventCtorTest() throws Fault {
		TEST_PROPS.setProperty(APITEST, "componentSystemEventCtorTest");
		invoke();
	}

	/**
	 * @testName: postValidateEventIAETest
	 * @assertion_ids: JSF:JAVADOC:1862
	 * @test_Strategy: Ensure an IllegalArgumentException is thrown if a a null
	 *                 component is passed to the PostValidateEvent constructor.
	 * 
	 * @since 2.0
	 */
	public void postValidateEventIAETest() throws Fault {
		TEST_PROPS.setProperty(APITEST, "componentSystemEventIAETest");
		invoke();
	}

	/**
	 * @testName: postValidateEventGetComponentTest
	 * @assertion_ids: JSF:JAVADOC:1862
	 * @test_Strategy: Ensure getComponent() returns the component passed to the
	 *                 PostValidateEvent constructor.
	 * 
	 * @since 2.0
	 */
	public void postValidateEventGetComponentTest() throws Fault {
		TEST_PROPS.setProperty(APITEST, "componentSystemEventGetComponentTest");
		invoke();
	}

	/**
	 * @testName: postValidateEventIsApproiateListenerPostiveTest
	 * @assertion_ids: JSF:JAVADOC:1862; JSF:JAVADOC:1876
	 * @test_Strategy: Ensure isAppropriateListener() Returns true if and only
	 *                 if the argument listener is an instance of
	 *                 SystemEventListener.
	 * 
	 * @since 2.0
	 */
	public void postValidateEventIsApproiateListenerPostiveTest() throws Fault {
		TEST_PROPS.setProperty(APITEST,
				"componentSystemEventIsApproiateListenerPostiveTest");
		invoke();
	}

	/**
	 * @testName: postValidateEventIsApproiateListenerNegativeTest
	 * @assertion_ids: JSF:JAVADOC:1862; JSF:JAVADOC:1876
	 * @test_Strategy: Ensure isAppropriateListener() Returns true if and only
	 *                 if the argument listener is *NOT* an instance of
	 *                 SystemEventListener.
	 * 
	 * @since 2.0
	 */
	public void postValidateEventIsApproiateListenerNegativeTest() throws Fault {
		TEST_PROPS.setProperty(APITEST,
				"componentSystemEventIsApproiateListenerNegativeTest");
		invoke();
	}

	/**
	 * @testName: postValidateEventProcessListenerTest
	 * @assertion_ids: JSF:JAVADOC:1862; JSF:JAVADOC:1877
	 * @test_Strategy: Ensure calling ComponentSystemEvent.processListener()
	 *                 calls through to
	 *                 ComponentSystemEventListener.processEvent().
	 * 
	 * @since 2.0
	 */
	public void postValidateEventProcessListenerTest() throws Fault {
		TEST_PROPS.setProperty(APITEST,
				"componentSystemEventProcessListenerTest");
		invoke();
	}
} // end of URLClient
