/*
 * Copyright (c) 20011, Oracle and/or its affiliates. All rights reserved.
 * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/*
 * $Id: URLClient.java 70324 2013-02-27 17:10:22Z dougd $
 */
package com.sun.ts.tests.jsf.spec.templating.component;

import java.io.PrintWriter;
import java.util.Formatter;

import com.gargoylesoftware.htmlunit.html.HtmlPage;
import com.gargoylesoftware.htmlunit.html.HtmlSpan;
import com.sun.javatest.Status;
import com.sun.ts.tests.jsf.common.client.BaseHtmlUnitClient;

public class URLClient extends BaseHtmlUnitClient {

	private static final String CONTEXT_ROOT = "/jsf_templating_component_web";

	public static void main(String[] args) {
		URLClient theTests = new URLClient();
		Status s = theTests.run(args, new PrintWriter(System.out, true),
				new PrintWriter(System.err, true));
		s.exit();
	}

	public Status run(String[] args, PrintWriter out, PrintWriter err) {
		return super.run(args, out, err);
	}

	/*
	 * @class.setup_props: webServerHost; webServerPort; ts_home;
	 */

	/**
	 * @testName: uicomponentVisableTest
	 * @assertion_ids: PENDING
	 * @test_Strategy: Test ui:component 'rendered' attribute with value of
	 *                 true.
	 * 
	 * @since 2.2
	 */
	public void uicomponentVisableTest() throws Fault {

		StringBuilder messages = new StringBuilder(128);
		Formatter formatter = new Formatter(messages);

		HtmlPage page = getPage(CONTEXT_ROOT + "/faces/visableTest.xhtml");

		HtmlSpan spanOne = (HtmlSpan) getElementOfTypeWithValue(page, "span",
				"rendered");

		if (!validateExistence("rendered", "span", spanOne, formatter)) {
			handleTestStatus(messages);
			return;
		}

		handleTestStatus(messages);
		formatter.close();

	} // END uicomponentVisableTest

	/**
	 * @testName: uicomponentNotVisableTest
	 * @assertion_ids: PENDING
	 * @test_Strategy: Test ui:component 'rendered' attribute with value of
	 *                 false.
	 * 
	 * @since 2.2
	 */
	public void uicomponentNotVisableTest() throws Fault {

		StringBuilder messages = new StringBuilder(128);
		Formatter formatter = new Formatter(messages);

		HtmlPage page = getPage(CONTEXT_ROOT + "/faces/notVisableTest.xhtml");

		if (page.getElementsByTagName("span").getLength() > 0) {
			formatter.format(
					"Unexpected '%s' element found when '%s' attribute on ui:compnent is "
							+ "set to '%s' ! ", "span", "rendered", "false");
		}

		handleTestStatus(messages);
		formatter.close();

	} // END uicomponentNotVisableTest

	/**
	 * @testName: uicomponentBindTest
	 * @assertion_ids: PENDING
	 * @test_Strategy: Test ui:component 'binding' attribute to make sure we
	 *                 bind correctly to a backend bean.
	 * 
	 * @since 2.2
	 */
	public void uicomponentBindTest() throws Fault {

		StringBuilder messages = new StringBuilder(128);
		Formatter formatter = new Formatter(messages);

		HtmlPage page = getPage(CONTEXT_ROOT + "/faces/component_binding.xhtml");

		HtmlSpan spanOne = (HtmlSpan) getElementOfTypeWithValue(page, "span",
				"Vidtily Chernobyl");

		if (!validateExistence("bind", "span", spanOne, formatter)) {
			handleTestStatus(messages);
			return;
		}

		handleTestStatus(messages);
		formatter.close();

	} // END uicomponentNotVisableTest

} // END URLClient

